@@ -304,7 +304,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            platform_id = self.get_manufacturers(name=platform_name)[0]['id']
+            platform_id = self.get_platforms(name=platform_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.patch('/dcim/platforms/', platform_id, **kwargs)
@@ -316,7 +316,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            platform_id = self.get_manufacturers(name=platform_name)[0]['id']
+            platform_id = self.get_platforms(name=platform_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.delete('/dcim/platforms/', platform_id)
@@ -325,46 +325,44 @@ class Dcim(object):
         """Return interfaces"""
         return self.netbox_con.get('/dcim/interfaces', **kwargs)
 
-    def get_interfaces_by_device(self, device_name, **kwargs):
-        """Get all interfaces by device
-
-        :param device_name: Name of device to get interfaces off
-        :return: list of interfaces
-        """
-        return self.netbox_con.get('/dcim/interfaces', device=device_name, **kwargs)
-
-    def create_interface(self, name, form_facter, device, **kwargs):
+    def create_interface(self, name, form_factor, device_id, **kwargs):
         """Create a new interface
 
         :param name: name of the interface
-        :param form_facter: interface type. It is not possible to get the list of form factors from the api. Search
+        :param form_factor: interface type. It is not possible to get the list of form factors from the api. Search
         in the netbox code for the correct form factor number.
         :param kwargs: optional arguments
-        :param device: name of the device to associate interface with
+        :param device_id: ID of the device to associate interface with
         :return: bool True if successful otherwise raise CreateException
         """
-        required_fields = {"name": name, "form_factor": form_facter, "device": device}
+        required_fields = {"name": name, "form_factor": form_factor, "device": device_id}
         return self.netbox_con.post('/dcim/interfaces/', required_fields, **kwargs)
 
-    def update_interface(self, interface, **kwargs):
+    def update_interface(self, interface, device, **kwargs):
         """Update interface
 
         :param interface: interface to update
+        :param device: name of the device
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            interface_id = self.get_manufacturers(name=interface)[0]['id']
+            interface_id = self.get_interfaces(name=interface, device=device)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('interface: {}'.format(interface)) from None
         return self.netbox_con.patch('/dcim/interfaces/', interface_id, **kwargs)
 
-    def delete_interface_by_id(self, interface_id):
-        """Delete interface by id
+    def delete_interface(self, interface_name, device):
+        """Delete platform
 
-        :param interface_id: id of interface to remove
+        :param interface_name: Name of interface to delete
+        :param device: Device to which the interface belongs
         :return: bool True if successful otherwise raise DeleteException
         """
+        try:
+            interface_id = self.get_interfaces(name=interface_name, device=device)[0]['id']
+        except IndexError:
+            raise exceptions.NotFoundException('interface: {}'.format(interface_name)) from None
         return self.netbox_con.delete('/dcim/interfaces/', interface_id)
 
     def get_interface_connections(self, **kwargs):
